@@ -6,14 +6,16 @@ name = 'web_2_album'
 import cached_url
 from bs4 import BeautifulSoup
 import export_to_telegraph
-from telegram_util import matchKey, cutCaption, getWid
+from telegram_util import matchKey, cutCaption, getWid, parseDomain
 from telegram_util import AlbumResult as Result
 import readee
 import time
 import yaml
+import sys
 
 IMG_CLASSES = ['f-m-img', 'group-pic', 'image-wrapper', 
-	'RichText', 'image-container']
+	'RichText', 'image-container', 'news_txt', "'article_con'", 
+	'photo_wrap', 'hideBeforeLoad', 'slide_container', 'rich_media_content']
 
 try:
 	with open('CREDENTIALS') as f:
@@ -39,8 +41,13 @@ def getCap(b, path):
 	return export_to_telegraph.exportAllInText(wrapper)
 
 def getCapForce(b, path):
-	if b.find('h1'):
-		return b.find('h1').text
+	for name in ['h1', 'h2']:
+		if b.find(name):
+			text = b.find(name).text
+			if 'douban' in path:
+				return text.split('-')[-1]
+			else:
+				return text
 	# don't know if this is the right thing to do, revisit if needed
 	center = readee.export(path, content = str(b))
 	try:
@@ -52,8 +59,9 @@ def isWeiboArticle(path):
 	return matchKey(path, ['card', 'ttarticle']) and 'weibo.c' in path
 
 def getSrc(img, path):
-	src = img.get('data-original') or img.get('data-actualsrc') or \
-		(img.get('src') and img.get('src').strip())
+	src = (img.get('data-full') or img.get('data-original') or 
+		img.get('data-actualsrc') or img.get('src') or img.get('data-src'))
+	src = src and src.strip()
 	if not src:
 		return 
 	if not img.parent or not img.parent.parent:
@@ -62,16 +70,32 @@ def getSrc(img, path):
 		if img.parent.name != 'a':
 			return
 		return img.parent['href']
+	if 'blog.boxun' in path:
+		return '/'.join(path.split('/')[:-1] + [src])
 	if isWeiboArticle(path) and 'sinaimg' in src:
 		return src
 	wrapper = img.parent.parent
+	if 'detail' in sys.argv:
+		print(str(wrapper.get('class')))
 	if matchKey(str(wrapper.get('class')) or '', IMG_CLASSES):
 		return src
 	return
 
+def enlarge(src):
+	if not src:
+		return None
+	return src.replace('/m/', '/l/')
+
+def withDomain(path, x):
+	if 'slideshare' in x:
+		x = x.split('?')[0]
+	if x and x[0] == '/':
+		return parseDomain(path) + x
+	return x
+
 def getImgs(b, path):
-	raw = [getSrc(img, path) for img in b.find_all('img')]
-	return [x for x in raw if x]
+	raw = [enlarge(getSrc(img, path)) for img in b.find_all('img')]
+	return [withDomain(path, x) for x in raw if x]
 
 def getVideo(b):
 	for video in b.find_all('video'):
